#!/bin/bash
#
# profil_ff.sh (v5)
# Script de synchronisation des profils firefox linux <-> windoze de l'utilisateur
# 20201002

ladate=$(date +%F+%T)
fichlog_ff=/home/$USER/logprofil_ff.log
fichlog=/home/$USER/session.log
dirclinux=/mnt/clinux

echo "# Debut exécution profil_ff.sh" >> $fichlog

# Inscription de la date en tête du log
echo $ladate > $fichlog_ff

# Test et création du répertoire mozilla linux s'il n'existe pas
if [ ! -e "/home/$USER/.mozilla/firefox" ]; then
echo "Le répertoire .mozilla/firefox n'existe pas, il faut le créer." >> $fichlog_ff
mkdir -p /home/$USER/.mozilla/firefox
else echo "Le répertoire .mozilla/firefox existe." >> $fichlog_ff
fi

# Création ou modification du profiles.ini pour linux
echo "[General]
StartWithLastProfile=1

[Profile0]
Name=default
IsRelative=1
Path=default" > /home/$USER/.mozilla/firefox/profiles.ini
echo "profiles.ini ff linux créé ou corrigé." >> $fichlog_ff

# S'il existe un profil ff linux nommé xxx.default ou xxx.default-esr : on le met de coté en le renommant
test_ff_tux=$(ls /home/$USER/.mozilla/firefox/ | grep [.]default$)
test_ff_tux_esr=$(ls /home/$USER/.mozilla/firefox/ | grep [.]default-esr$)
test_ff_tux_rel=$(ls /home/$USER/.mozilla/firefox/ | grep [.]default-release$)
if [ -n "$test_ff_tux" ]; then
echo "Il existe un repertoire xxx.default pour ff tux. On le renomme." >> $fichlog_ff
mv /home/$USER/.mozilla/firefox/*.default /home/$USER/.mozilla/firefox/default.old_$ladate
elif [ -n "$test_ff_tux_esr" ]; then
echo "Il existe un repertoire xxx.default-esr pour ff tux. On le renomme." >> $fichlog_ff
mv /home/$USER/.mozilla/firefox/*.default-esr /home/$USER/.mozilla/firefox/default-esr.old_$ladate
elif [ -n "$test_ff_tux_rel" ]; then
echo "Il existe un repertoire xxx.default-release pour ff tux. On le renomme." >> $fichlog_ff
mv /home/$USER/.mozilla/firefox/*.default-release /home/$USER/.mozilla/firefox/default-release.old_$ladate
else
echo "Pas de répertoire xxx.default* pour ff tux. On continue." >> $fichlog_ff
fi


# Création ou modification du profiles.ini pour windoze
echo "[General]
StartWithLastProfile=1

[Profile0]
Name=default
IsRelative=1
Path=Profiles/default" > /home/$USER/AppData/Roaming/Mozilla/Firefox/profiles.ini
echo "profiles.ini ff windoze créé ou corrigé." >> $fichlog_ff

# S'il existe un profil ff windoze nommé xxx.default* : on le garde et on le renomme en default
test_ff_win=$(ls /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles | grep [.]default$)
test_ff_win_esr=$(ls /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles | grep [.]default-esr$)
test_ff_win_rel=$(ls /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles | grep [.]default-release$)
test_default_win=$(ls /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles | grep -o ^default$)

if [ -n "$test_ff_win" ]; then
echo "Il existe un dossier ff xxx.default pour windoze, on le renomme." >> $fichlog_ff
mv /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/*.default /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/default.old_$ladate
elif [ -n "$test_ff_win_esr" ]; then
echo "Il existe un dossier ff xxx.default-esr pour windoze, on le renomme." >> $fichlog_ff
mv /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/*.default-esr /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/default-esr.old_$ladate
elif [ -n "$test_ff_win_rel" ]; then
echo "Il existe un dossier ff xxx.default-release pour windoze, on le renomme." >> $fichlog_ff
mv /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/*.default-release /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/default-release.old_$ladate
elif [ -n "$test_default_win" ]; then
echo "Le dossier default ff pour windoze existe." >> $fichlog_ff
else
echo "Le dossier default ff pour windoze n'existe pas, il faut le créer." >> $fichlog_ff
mkdir -p /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/default
echo "Dossier default ff pour windoze créé." >> $fichlog_ff
fi

# synchro des profils ff
winffdir="/home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/default"
if [ -n "`ls -A $winffdir`" ]; then
echo "" >> $fichlog_ff
echo "Le répertoire de profil ff windoze n'est pas vide, on synchronise..." >> $fichlog_ff
echo "Synchro FF windoze -> linux..." >> $fichlog_ff
echo "Synchro FF windoze -> linux..." >> $fichlog
rsync -av /home/$USER/AppData/Roaming/Mozilla/Firefox/Profiles/default/* /home/$USER/.mozilla/firefox/default/ >> $fichlog_ff
else
	if [ ! -e "/home/$USER/.mozilla/firefox/default" ]; then
	echo "Le répertoire .mozilla/firefox/default n'existe pas, on le crée." >> $fichlog_ff
	mkdir -p /home/$USER/.mozilla/firefox/default
	else echo "Le répertoire .mozilla/firefox/default existe." >> $fichlog_ff
	fi
fi

echo "" >> $fichlog_ff

# Correction des droits
chown -R $USER:domain\ users /home/$USER

echo ""
echo "# Fin exécution profil_ff.sh" >> /home/$USER/session.log
echo ""
echo "Traitement des profils ff linux <-> windoze terminé." >> $fichlog_ff
echo ""

exit 0

